@@ -70,7 +70,20 @@ before 'COMPONENT' => sub {
 
 sub process { (shift)->approot(@_) }
 
-sub approot :Chained :PathPrefix :Args {
+# --- Update to GitHub PR #142 ---
+# SWITCHED approot FROM :Chained BACK TO ORIGINAL :Path
+#
+# 'approot' is the special controller action which is the catch-all that hands
+# off the dispatch into the Module controller hierarchy, which is a very non-standard
+# setup in terms of the Catalyst dispatcher. The switch to :Chained in PR #142
+# for approot results in it getting higher priority than locally defined :Path
+# controllers - which we don't want - so for now we're switching just this action 
+# back to :Path. The rest of the controller actions that were switched to :Chained 
+# in PR #142 are working fine and will be kept as-is, since :Chained is still preferred.
+# TODO: revisit this again to see if there is a better solution...
+#
+#sub approot :Chained :PathPrefix :Args {
+sub approot :Path {
   my ($self, $c, @args) = @_;
 
   # Handle url string mode:
