@@ -2,6 +2,18 @@ package RapidApp::Include;
 use strict;
 use warnings;
 
+die join("\n",
+  '','',
+  '  ***  WARNING  ***',
+  "  " . __PACKAGE__ . " is DEPRECATED. It has been replaced by consolidated 'RapidApp::Util' package",
+  "   [tip]: run `upgr-rapidapp.pl path/to/lib/` to upgrade your code automatically...",
+  '',''
+);
+
+1;
+__END__
+
+
 
 =head1 NAME
 
